# apkg

**apkg** is a free and open source minimalist cross-distro **upstream packaging
automation tool** aimed at producing high quality native packages for many
different OS distributions/packaging systems directly from upstream sources with
minimum overhead while respecting individual distros' standards and policies.

It's a stable CLI optimized for both CI systems and terminal.

Please read the [docs]:

# [apkg docs online][docs]

## [apkg docs on GitLab](https://gitlab.nic.cz/packaging/apkg/-/blob/master/docs/index.md)

## apkg docs from sources

See `docs/index.md` and other files in `docs/` directory.

You can also render docs into HTML using `mkdocs`:

    pip install -r doc-requirements.txt
    mkdocs build
    browser site/index.html

#### read the [docs] and have a nice packaging ᕕ( ᐛ )ᕗ


[docs]: https://pkg.labs.nic.cz/pages/apkg
